@@ -272,7 +272,7 @@ class SetupLink(LoggerMixin):  # pylint: disable=too-many-instance-attributes
             elif index > 0 and self._transfer_agent.all_host_addr[index] in self._transfer_agent.authenticated_hosts:
                 self._agent_item.move()  # blocking
                 index += 1
-            if self._is_terminate_query_ssh:
+            if self._is_terminate_query_scp:
                 break
             sleep(0.1)  # otherwise, tk might behaves erratic
 
@@ -375,7 +375,7 @@ class StateVisualiser:  # pylint: disable=too-few-public-methods
 
     def start(self):
         """Start continuously determining the state of the tunnel."""
-        self._status_item.show('established')
+        self._status_item.show('opened')
         self._animated_packet.start()
         while not self._heartbeat.terminate:
             if not self._heartbeat.is_tunnel_intact:
