@@ -514,9 +514,7 @@ class AgentCanvasItem(CanvasItem):  # pylint: disable=too-many-instance-attribut
 
     def transfer_nok(self):
         """Colours the outline red and changes the outline to have a dashed pattern."""
-        self._canvas_landscape.itemconfig(self.item_tag, dash=(5, 5))
-        self._canvas_landscape.itemconfig(self.item_tag, outline=NOK_COLOUR)
-        self._canvas_landscape.itemconfig(self.item_tag, width=THICKNESS_LINE_AGENT)
+        self._canvas_landscape.itemconfig(self.item_tag, dash=(5, 5), outline=NOK_COLOUR, width=THICKNESS_LINE_AGENT)
 
     def setup_ok(self):
         self._agent_effect.setup_ok()
@@ -637,7 +635,7 @@ class StatusBannerCanvasItem(CanvasItem):
         pos_x = width / 2
         status_height = self._canvas_status.winfo_height()
         pos_y = status_height / 2
-        text = 'UNESTABLISHED'.center(30)
+        text = 'NO TUNNEL'.center(30)
         self._canvas_status.create_text(pos_x,
                                         pos_y,
                                         text=text,
@@ -664,21 +662,21 @@ class StatusBannerCanvasItem(CanvasItem):
         if state is None:
             self._canvas_status.itemconfig(self._tag_text_item, state='normal')
             self._text_effect.flicker()
-        elif state == 'established':
-            text = 'CONNECTION ESTABLISHED'.center(30)
+        elif state == 'opened':
+            text = 'TUNNEL OPENED'.center(30)
             self._canvas_status.itemconfig(self._tag_text_item, text=text, fill=OK_COLOUR)
         elif state == 'broken':
-            text = 'CONNECTION BROKEN'.center(30)
+            text = 'TUNNEL BROKEN'.center(30)
             self._canvas_status.itemconfig(self._tag_text_item, text=text, fill=NOK_COLOUR)
         elif state == 'restored':
-            text = 'CONNECTION RESTORED'.center(30)
+            text = 'TUNNEL RESTORED'.center(30)
             self._canvas_status.itemconfig(self._tag_text_item, text=text, fill=OK_COLOUR)
 
     def _show_box(self, state=None):
         if state is None:
             self._canvas_status.itemconfig(self._tag_box_item, state='normal')
             self._box_effect.flicker()
-        if state == 'established':
+        if state == 'opened':
             self._canvas_status.itemconfig(self._tag_box_item, outline=OK_COLOUR)
         elif state == 'broken':
             self._canvas_status.itemconfig(self._tag_box_item, outline=NOK_COLOUR)
@@ -701,7 +699,7 @@ class StatusBannerCanvasItem(CanvasItem):
         pass
 
     def dim(self):
-        text = 'UNESTABLISHED'.center(26)
+        text = 'TUNNEL CLOSED'.center(26)
         self._canvas_status.itemconfig(self._tag_text_item, text=text)
         self._text_effect.dim()
         self._box_effect.dim()
